/*
** Module   : HQLTypes.java
** Abstract : Enumeration of data types for various HQL constructs
**
** Copyright (c) 2004-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------Description-----------------
** 001 ECF 20080310  @37500  Created initial version. Enumeration of data
**                           types for various HQL constructs.
** 002 ECF 20080805  @39311  Added rowid support. Added LONG type.
** 003 SVL 20120331          Added DATETIME and DATETIMETZ types.
*/

package com.goldencode.p2j.persist.hql;

/**
 * Enumeration of data types for various HQL constructs.  This common form
 * is used to rationalize all the various type constructs (token types, Java
 * class types, Hibernate types) into a common vocabulary.
 */
public enum HQLTypes
{
   /** Boolean data type */
   BOOLEAN,
   
   /** 32-bit integer data type */
   INTEGER,
   
   /** 64-bit integer data type */
   LONG,
   
   /** Decimal data type */
   DECIMAL,
   
   /** Double data type */
   DOUBLE,
   
   /** Text/string data type */
   TEXT,
   
   /** Date data type */
   DATE,
   
   /** Binary (byte array) data type */
   RAW,

   /** Date/time data type */
   DATETIME,

   /** Date/time with time zone data type */
   DATETIMETZ,
   
   /** Unknown data type */
   UNKNOWN,
}
